@@ -36,6 +36,8 @@ var Events = map[string]string{
 	"customer.subscription.created":            "triggers/customer.subscription.created.json",
 	"customer.subscription.deleted":            "triggers/customer.subscription.deleted.json",
 	"customer.subscription.updated":            "triggers/customer.subscription.updated.json",
+	"customer.subscription.paused":             "triggers/customer.subscription.paused.json",
+	"customer.subscription.trial_will_end":     "triggers/customer.subscription.trial_will_end.json",
 	"identity.verification_session.canceled":   "triggers/identity.verification_session.canceled.json",
 	"identity.verification_session.created":    "triggers/identity.verification_session.created.json",
 	"identity.verification_session.redacted":   "triggers/identity.verification_session.redacted.json",
@@ -46,6 +48,12 @@ var Events = map[string]string{
 	"invoice.payment_failed":                   "triggers/invoice.payment_failed.json",
 	"invoice.payment_succeeded":                "triggers/invoice.payment_succeeded.json",
 	"invoice.updated":                          "triggers/invoice.updated.json",
+	"invoice.deleted":                          "triggers/invoice.deleted.json",
+	"invoice.voided":                           "triggers/invoice.voided.json",
+	"invoice.sent":                             "triggers/invoice.sent.json",
+	"invoice.marked_uncollectible":             "triggers/invoice.marked_uncollectible.json",
+	"invoiceitem.created":                      "triggers/invoiceitem.created.json",
+	"invoiceitem.deleted":                      "triggers/invoiceitem.deleted.json",
 	"issuing_authorization.request":            "triggers/issuing_authorization.request.json",
 	"issuing_authorization.request.eu":         "triggers/issuing_authorization.request.eu.json",
 	"issuing_authorization.request.gb":         "triggers/issuing_authorization.request.gb.json",
